package Config::Restaurants;

use utf8;

# https://www.chaps.cz/files/idos/IDOS-API.pdf
my $bus32 = 'Bus spoj: https://jizdnirady.idnes.cz/brno/spojeni/?f=Botanick%C3%A1&t=Su%C5%A1ilova&submit=true';

# primarne hladat Zomato, kedze odtial vieme data tahat cistym sposobom
# aj pri pouziti Zomato je ale fajn mat uvedene fallback_url, ak nevyplnia alebo co


our $restaurants = {
    'padthai' => {
        'type' => 'zomato',
        'site_id' => 16506806,
    },
    'everest' => {
        'type' => 'zomato',
        'site_id' => 16506537,
        'aliases' => [qw(eve)],
        'fallback_url' => 'https://www.everestbrno.cz/denni-menu/', # parseable
        'note' => $bus32,
    },
    'himalaya' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/pg/THRABB18/posts/, https://www.himalayarestaurace.cz/denni-menu/', # unparseable
        'aliases' => [qw(himalaya)],
    },
    'ubilehoberanka' => {
        'type' => 'zomato',
        'site_id' => 16506737,
        'aliases' => [qw(beranek bilyberanek uberanka)],
        'fallback_url' => 'https://www.ubilehoberanka.cz/en/daily-menu', # parseable
    },
    'selepka' => {
        'type' => 'zomato',
        'site_id' => 16506040,
        'fallback_url' => 'http://www.selepova.cz/denni-menu/', # parseable
    },
    'suzies' => {
        'type' => 'zomato',
        'site_id' => 18126190,
        'note' => $bus32,
    },
    'cattani' => {
        'type' => 'showurl',
        'aliases' => [qw(catani katani)],
        'menu_url' => 'http://www.cattani.cz/, https://www.menicka.cz/3179-cattani---josefska.html',
    },
    'udrevaka' => {
        'type' => 'zomato',
        'site_id' => 16505458,
        'aliases' => [qw(drevak)],
        'fallback_url' => 'https://www.udrevaka.cz/denni-menu/', # parseable
    },
    'vegalite' => {
        'type' => 'showurl',
        'menu_url' => 'http://vegalite.cz/#denni-menu, https://www.menicka.cz/2775-vegalite.html', # parseable
    },
    'siwa' => {
        'type' => 'zomato',
        'site_id' => 18578705,
    },
    'goldennepal' => {
        'type' => 'showurl',
        'aliases' => [qw(golden gn)],
        'menu_url' => 'https://www.golden-nepal.cz/denni-menu/', # parseable
    },
    'divabara' => {
        'type' => 'zomato',
        'site_id' => 16514047,
        'fallback_url' => 'http://www.restauracedivabara.cz/menu/',
    },
    'annapurna' => {
        'type' => 'showurl',
        'menu_url' => 'http://indicka-restaurace-annapurna.cz/images/tydenijidelnicek/menu.pdf', # pdftotext + parseable
        'aliases' => [qw(anapurna)],
    },
    'tivoli' => {
        'type' => 'showurl',
        'menu_url' => 'http://tivolicafe.cz/menu/poledni-menu/',
    },
    'alcapone' => {
        'type' => 'module',
        'module' => 'Obedar::AlCapone',
    },
    'lightofindia' => {
        'type' => 'module',
        'module' => 'Obedar::LightOfIndia',
        'aliases' => [qw(light)],
        'fallback_url' => 'http://www.lightofindia.cz/lang-cs/denni-menu',
    },
    'sabaidy' => {
        'type' => 'module', # existuje i zomato (16512604), ale menu tam nedavaju
        'module' => 'Obedar::Sabaidy',
        'fallback_url' => 'http://www.amphone.eu/poledni-menu',
    },
    'lastrada' => {
        'type' => 'module',
        'module' => 'Obedar::LaStrada',
        'fallback_url' => 'http://lastrada-brno.cz/poledni-menu/',
        'note' => $bus32,
    },
    'nepal' => {
        'type' => 'module',
        'module' => 'Obedar::NepalBrno',
    },
    'klubcestovatelu' => {
        'type' => 'module',
        'module' => 'Obedar::KlubCestovateluBrno',
    },
    'madanmohan' => {
        'type' => 'showurl',
        'menu_url' => 'http://www.madanmohan.cz/menu',
        'aliases' => [qw(avatar)],
    },
    'buddha' => {
        'type' => 'module',
        'module' => 'Obedar::Buddha',
        'note' => $bus32,
    },
    'khaybar' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/pg/Indická-Restaurace-Khaybar-184987895598026/posts/',
    },
    'veselacajovna' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.veselacajovna.cz/tydenni-nabidka/',
    },
    'haribol' => {
        'type' => 'nomenu',
    },
    'chutnestesti' => {
        'type' => 'nomenu',
    },
    'lokofu' => {
        'type' => 'nomenu',
    },
    'vietnam' => {
        'type' => 'showurl',
        'menu_url' => 'https://drive.google.com/open?id=11rTYbOZUAOphVS9svpy6EW-nrCs&usp=sharing',
        'aliases' => [qw(pho)],
    },
    'ellas' => {
        'type' => 'nomenu',
    },
    'newbambay' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/newbambay.cz',
        'aliases' => [qw(bambay)],
    },
    'makalu' => {
        'type' => 'showurl',
        'menu_url' => 'http://www.nepalska-restaurace-makalu.cz/#TMenu',
    },
    'lasperanza' => {
        'type' => 'nomenu',
    },
    'indiathali' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/indiathali13/',
    },
    'boulevard' => {
        'type' => 'zomato',
        'site_id' => 16505876,
        'fallback_url' => 'http://www.boulevardrestaurant.cz/poledniacute-menu.html',
    },
    'namaskar' => {
        'type' => 'showurl',
        'menu_url' => 'http://www.namaskar.cz/denni-menu/',
    },
    'bishesgurkha' => {
        'type' => 'showurl',
        'menu_url' => 'http://bishesgurkha.cz/?page_id=804',
        'aliases' => [qw(bishes gurkha)],
    },
    'namaskarsmetanova' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/pg/Namaskarbrno/posts/',
        'aliases' => [qw(namaskar2)],
        'note' => "Pozor, obsahuje i menu Namaskaru Taborska. $bus32",
    },
    'jednabasen' => {
        'type' => 'zomato',
        'site_id' => 16506578,
        'fallback_url' => 'http://www.jedna-basen.cz/bar/denni-menu/',
        'aliases' => [qw(basen)],
    },
    'singha' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/pg/singhabrno/posts/',
    },
    'tao' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/pg/Táo-Viet-Nam-Home-Cooking-Sushi-Bar-1857934510936812/posts/',
    },
    'padagali' => {
        'type' => 'showurl',
        'menu_url' => 'http://padagali.cz/denni-menu/, https://www.menicka.cz/4116-padagali.html', # parseable
    },
    'lloyds' => {
        'type' => 'zomato',
        'site_id' => 16506456,
        'fallback_url' => 'http://restauracelloyds.cz/menu-2/denni-menu/',
        'aliases' => [qw(lloyd)],
    },
    'tasteofindia' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.taste-of-india.cz/#daily-menu',
        'aliases' => [qw(taste)],
    },
    'naruzku' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.naruzkubrno.cz/tydenni-menu/',
    },
    'ukarla' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/pg/UKarlaBrno/posts/?ref=page_internal',
        'aliases' => [qw(karel)],
    },
    'pilgrim' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/pilgrims.cz/', # unparseable
    },
    'mahostina' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.mahostina.cz/dnesnibasta', # parseable
    },
    'umachala' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.menicka.cz/6559-bistro-u-machala.html, http://www.bistroumachala.cz/', # parseable
        'aliases' => [qw(machal sfinx)],
    },
    'triocasci' => {
        'type' => 'showurl',
        'menu_url' => 'https://triocasci.cz/jidlo/', # parseable
        'aliases' => [qw(ocasci ocas)],
    },
    'nachate' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.restauracenachate.cz/tydenni-menu.php', # parseable
    },
    'luzanka' => {
        'type' => 'showurl',
        'menu_url' => 'https://luzankabrno.cz/poledni-menu/', # parseable
    },
    'mayada' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/MAYADA.ghazal123/',
    },
    'casadelgusto' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/casadelgusto.brno/',
        'aliases' => [qw(casa gusto)],
    },
    'tesnevedle' => {
        'type' => 'showurl',
        'menu_url' => 'http://www.tesnevedle.cz/tydenni-menu', # parseable
    },
    'olymp' => {
        'type' => 'showurl',
        'menu_url' => 'http://www.olymp-pub.cz/edit/menu.pdf',
    },
    'ustaryhobilla' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.billexpress.cz/eshop/',
        'aliases' => [qw(bill ubilla)],
    },
    'bistrovprocesu' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.facebook.com/Bistro-v-Procesu-100433491751360/',
        'aliases' => [qw(vprocesu proces)],
    },
    'fabrikfoodfactory' => {
        'type' => 'showurl',
        'menu_url' => 'https://factory.fabrik.cz/denni-menu/', # parseable
        'aliases' => [qw(fabrik)],
    },
    'efihostinec' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.efishop.cz/efi-hostinec/', # parseable
        'aliases' => [qw(efi)],
    },
    'prvnidoubravnicka' => {
        'type' => 'showurl',
        'menu_url' => 'https://www.prvnidoubravnicka.cz/menu',
        'aliases' => [qw(doubravnicka)],
    },
};

1;
